@@ -17,10 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Search.py,v 1.8 1999/09/15 09:29:27 gobry Exp $
+# $Id: Search.py,v 1.9 1999/09/24 07:18:36 gobry Exp $
 
 from gnome.ui import *
 from gtk import *
+import GTK
 
 import string, re, sys, traceback, copy
 
@@ -119,7 +120,6 @@ class SearchDialog (GtkDialog):
         self.set_usize (400, 500)        
         self.connect("delete_event", self.close)
 
-        self.data  = data
         self.pairs   = []
         
         # Buttons
@@ -186,9 +186,6 @@ class SearchDialog (GtkDialog):
 
         self.vbox.pack_start (holder)
 
-        self.root_item = ItemStorage ('Full database', self.data.data)
-        self.root_tree.append (self.root_item)
-
         # connect a menu to the right button
         self.root_tree.connect ("button_press_event", self.popup_menu)
 
@@ -196,9 +193,26 @@ class SearchDialog (GtkDialog):
         self.delete_button = popup_add (self.menu, "Delete",  self.search_delete)
         self.menu.show ()
 
-        self.status.push (1, 'Ready to search !')
+        self.root_item = None
+        self.create_root_item (data)
         return
 
+    def create_root_item (self, data):
+        self.data = data
+
+        if self.root_item:
+            self.root_item.remove_subtree ()
+            self.root_tree.remove (self.root_item)
+            
+        # initialize the tree with the full database
+        self.root_item = ItemStorage ('Full database', self.data.data)
+        self.root_tree.append (self.root_item)
+        self.root_item.show ()
+
+        self.status.pop  (1)
+        self.status.push (1, 'Ready to search !')
+        return
+    
     
     def apply (self, widget):
         if self.data.data is None: return
