@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtex.c,v 1.21 1999/08/31 13:08:46 gobry Exp $
+ $Id: bibtex.c,v 1.23 1999/09/24 07:15:45 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -79,6 +79,7 @@ add_to_dico (gpointer key, gpointer value, gpointer user) {
     }
     
     field = (BibtexField *) value;
+    g_strdown (val);
 
     g_hash_table_insert ((GHashTable *) user, val, field->structure);
 }
@@ -125,15 +126,30 @@ bibtex_source_next_entry (BibtexSource * file,
 		    }
 		}
 		else {
-		    if (strcasecmp (ent->type, "preamble") == 0) {
-			if (filter) {
-			    bibtex_warning ("%d: skipping preamble", file->line);
-			
+		    do {
+			if (strcasecmp (ent->type, "comment") == 0) {
 			    bibtex_entry_destroy (ent, TRUE);
 			    ent = NULL;
+			    
+			    break;
 			}
-		    }
-		    else {
+
+			if (strcasecmp (ent->type, "preamble") == 0) {
+			    if (filter) {
+				bibtex_warning ("%s:%d: skipping preamble",
+						file->name, file->line);
+				
+				bibtex_entry_destroy (ent, TRUE);
+				ent = NULL;
+			    }
+			    else {
+			        /* flatten the preamble */
+			        ent->preamble = 
+				   bibtex_struct_flatten (ent->preamble);
+			    }
+			    break;
+			}
+
 			/* normal case; convert preamble into entry name */
 			if (ent->preamble) {
 			    if (ent->preamble->type == BIBTEX_STRUCT_REF) {
@@ -155,7 +171,7 @@ bibtex_source_next_entry (BibtexSource * file,
 			    
 			    return NULL;
 			}
-		    }
+		    } while (0);
 		}
 	    }
 	}
